TimerCase

Enum TimerCase 

pub enum TimerCase {
    NotExist,
    Begin,
    Interval {
        begin: u64,
        end: u64,
    },
    ReadFailed,
    TimeDecreased {
        a: u64,
        b: u64,
    },
    SetTimer,
    UnexpectedTrap(Trap<usize, usize>),
    Pass,
}
Timer programmer extension test cases.

Variants



NotExist

Can’t proceed test for Timer extension does not exist.



Begin

Test begin.



Interval

Test process for time interval overhead between two reads.

Fields

begin: u64

The time counter value for the first read.

end: u64

The time counter value for the second read.



ReadFailed

Test failed for can’t read time register.



TimeDecreased

Test failed for time counter has decreased during period of two reads.

Fields

a: u64

The time counter value for the first read.

b: u64

The time counter value for the second read.



SetTimer

Test process for timer has been set.



UnexpectedTrap(Trap<usize, usize>)

Test failed for unexpected trap during timer test.



Pass

All test cases on timer extension has passed.