pub enum DbcnCase {
Show 14 variants
NotExist,
Begin,
WriteByte,
WritingByteFailed(SbiRet),
WriteSlice,
WritingPartialSlice(usize),
WritingSliceFailed(SbiRet),
Read(usize),
ReadingFailed(SbiRet),
NonzeroUpperWriteRejected(SbiRet),
NonzeroUpperWriteAccepted(usize),
NonzeroUpperReadRejected(SbiRet),
NonzeroUpperReadAccepted(usize),
Pass,
}Expand description
Debug console extension test cases.
Variants
NotExist
Can’t proceed test for debug console extension does not exist.
Begin
Test begin.
WriteByte
Test process for write a byte to console.
WritingByteFailed(SbiRet)
Test failed for can’t write byte.
WriteSlice
Test process for write complete slice.
WritingPartialSlice(usize)
Test process for write partial slice.
WritingSliceFailed(SbiRet)
Test failed for can’t write slice.
Read(usize)
Test process for read some bytes from console.
ReadingFailed(SbiRet)
Test failed for can’t read to buffer.
NonzeroUpperWriteRejected(SbiRet)
Test process for rejecting a write with a non-zero upper address half.
NonzeroUpperWriteAccepted(usize)
Test failed because a write with a non-zero upper address half was accepted.
NonzeroUpperReadRejected(SbiRet)
Test process for rejecting a read with a non-zero upper address half.
NonzeroUpperReadAccepted(usize)
Test failed because a read with a non-zero upper address half was accepted.
Pass
All test cases on debug console extension has passed.