pub enum HsmCase<'a> {
Show 15 variants
NotExist,
Begin,
HartStartedBeforeTest(usize),
NoStoppedHart,
BatchBegin(&'a [usize]),
HartStarted(usize),
HartStartFailed {
hartid: usize,
ret: SbiRet,
},
HartSuspendedNonretentive(usize),
HartResumed(usize),
HartSuspendedRetentive(usize),
HartStopped(usize),
RemoteRFencePass(usize),
RemoteRFenceFailed(usize, SbiRet),
BatchPass(&'a [usize]),
Pass,
}Expand description
Hart state monitor extension test cases.
Variants
NotExist
Can’t proceed test for Hart state monitor extension does not exist.
Begin
Test begin.
HartStartedBeforeTest(usize)
Test failed for hart started before test begin.
The returned value includes which hart led to this test failure.
NoStoppedHart
Test failed for no other harts are available to be tested.
BatchBegin(&'a [usize])
Test process for begin test hart state monitor on one batch.
HartStarted(usize)
Test process for target hart to be tested has started.
HartStartFailed
Test failed for can’t start target hart with SbiRet error.
Fields
HartSuspendedNonretentive(usize)
Test process for target hart to be tested has non-retentively suspended.
HartResumed(usize)
Test process for target hart to be tested has resumed.
HartSuspendedRetentive(usize)
Test process for target hart to be tested has retentively suspended.
HartStopped(usize)
Test process for target hart to be tested has stopped.
RemoteRFencePass(usize)
Remote RFence succeeded on a started remote hart.
RemoteRFenceFailed(usize, SbiRet)
Remote RFence failed on a started remote hart.
BatchPass(&'a [usize])
Test process for harts on current batch has passed the tests.
Pass
All test cases on hart state monitor module finished.